"""Medium API.
"""

import requests

from datahunters.social.common import SocialUser


class MediumAPI(object):
  BASE_URL = "https://api.medium.com/v1"

  def __init__(self, client_id, client_secret):
    pass
