"""Crawler for amazon products.
"""

import amazonproduct

class AmazonParams(object):
  """Parameters for crawling amazon.
  """
  pass

class AmazonCrawler(object):
  """Crawler class for amazon products.
  """
  def __init__(self):
    pass